@@ -27,10 +27,11 @@ my $cgi = Lemonldap::NG::Manager::Sessions->new(
     }
 ) or Lemonldap::NG::Common::CGI->abort('Unable to start sessions explorer');
 
-my $skin     = $cgi->{managerSkin} or $cgi->abort('managerSkin is not defined');
-my $css      = 'tree.css';
-my $skin_dir = 'skins';
-my $main_dir = $ENV{DOCUMENT_ROOT};
+my $skin = $cgi->{managerSkin} or $cgi->abort('managerSkin is not defined');
+my $css = 'tree.css';
+my $css_theme = 'ui-lightness';
+my $skin_dir  = 'skins';
+my $main_dir  = $ENV{DOCUMENT_ROOT};
 
 my $template = HTML::Template->new(
     filename          => "$main_dir/$skin_dir/$skin/sessions.tpl",
@@ -38,11 +39,11 @@ my $template = HTML::Template->new(
     cache             => 0,
     filter            => sub { $cgi->translate_template(@_) },
 );
-$template->param( SCRIPT_NAME    => $ENV{SCRIPT_NAME} );
-$template->param( TREE           => $cgi->tree() );
-$template->param( DIR            => "$skin_dir/$skin" );
-$template->param( TREE_AUTOCLOSE => $cgi->{managerTreeAutoClose} );
-$template->param( CSS            => $css );
+$template->param( SCRIPT_NAME => $ENV{SCRIPT_NAME} );
+$template->param( TREE        => $cgi->tree() );
+$template->param( DIR         => "$skin_dir/$skin" );
+$template->param( CSS         => $css );
+$template->param( CSS_THEME   => $css_theme );
 print $cgi->header('text/html; charset=utf-8');
 print $template->output;
 
